@@ -647,6 +647,7 @@ void KateViewManager::removeViewSpace (KateViewSpace *viewspace)
       // save current splitter size, as the removal of currentSplitter looses the info
       QList<int> parentSizes = parentSplitter->sizes();
       parentSplitter->insertWidget (index, currentSplitter->widget (0));
+      currentSplitter->hide(); // see bug #232140
       delete currentSplitter;
       // now restore the sizes again
       parentSplitter->setSizes(parentSizes);
@@ -657,6 +658,8 @@ void KateViewManager::removeViewSpace (KateViewSpace *viewspace)
     // we are the root splitter and have only one child, which is also a splitter
     // -> eliminate the redundant splitter and move both children into the root splitter
     QList<int> sizes = splitter->sizes();
+    // adapt splitter orientation to the splitter we are about to delete
+    currentSplitter->setOrientation(splitter->orientation());
     currentSplitter->addWidget( splitter->widget(0) );
     currentSplitter->addWidget( splitter->widget(0) );
     delete splitter;
