@@ -7,7 +7,7 @@
    published by the Free Software Foundation; either version 2 of
    the License or (at your option) version 3 or any later version
    accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy 
+   by the membership of KDE e.V.), which shall act as a proxy
    defined in Section 14 of version 3 of the license.
 
    This program is distributed in the hope that it will be useful,
@@ -21,7 +21,6 @@
 #include "messageeditor.h"
 
 #include <QLabel>
-#include <QComboBox>
 #include <QPushButton>
 #include <QVBoxLayout>
 #include <QFrame>
@@ -29,6 +28,7 @@
 #include <QHBoxLayout>
 #include <QBoxLayout>
 
+#include <kcombobox.h>
 #include <ktextedit.h>
 #include <kinputdialog.h>
 #include <klocale.h>
@@ -58,7 +58,7 @@ MessageEditor::MessageEditor( QWidget *parent )
   QLabel *selectionLabel = new QLabel(i18n("Button:"), topFrame);
   selectionLayout->addWidget(selectionLabel);
 
-  mSelectionCombo = new QComboBox(topFrame);
+  mSelectionCombo = new KComboBox(topFrame);
   selectionLayout->addWidget(mSelectionCombo);
   connect(mSelectionCombo,SIGNAL(activated(int)),SLOT(changeMessage()));
 
@@ -83,7 +83,7 @@ void MessageEditor::updateConfig()
   mSelectionCombo->clear();
 
   QMap<QString,QString>::ConstIterator it;
-  for(it = mMessageButtons.begin();it != mMessageButtons.end();++it) {
+  for(it = mMessageButtons.constBegin();it != mMessageButtons.constEnd();++it) {
     mSelectionCombo->addItem(it.key());
   }
 
