@@ -24,10 +24,11 @@
 #include "treemap.h"
 
 #include <math.h>
-
+#include <QAction>
+#include <QMenu>
+#include <QApplication>
 #include <QDebug>
 #include <QPainter>
-#include <QRegExp>
 #include <QStyle>
 #include <QPixmap>
 #include <QPaintEvent>
@@ -36,8 +37,8 @@
 #include <QContextMenuEvent>
 #include <QMouseEvent>
 #include <QToolTip>
-#include <Qt3Support/Q3PtrList>
-#include <Qt3Support/Q3PopupMenu>
+#include <QStylePainter>
+#include <QStyleOptionFocusRect>
 
 
 // set this to 1 to enable debug output
@@ -629,7 +630,7 @@ bool RectDrawing::drawField(QPainter* p, int f, DrawParams* dp)
       pixDrawn = false;
   }
 
-  // width of text and pixmap to be drawn	
+  // width of text and pixmap to be drawn
   int w = pixW + _fm->width(name);
 
   if (0) qDebug() << "  For '" << name << "': Unused " << unused
@@ -792,41 +793,40 @@ bool RectDrawing::drawField(QPainter* p, int f, DrawParams* dp)
 // TreeMapItemList
 //
 
-int TreeMapItemList::compareItems ( Item item1, Item item2 )
-{
-  bool ascending;
-  int result;
-
-  TreeMapItem* parent = ((TreeMapItem*)item1)->parent();
-  // should not happen
-  if (!parent) return 0;
-
-  int textNo = parent->sorting(&ascending);
-
-  if (textNo < 0) {
-    double diff = ((TreeMapItem*)item1)->value() -
-                  ((TreeMapItem*)item2)->value();
-    result = (diff < -.9) ? -1 : (diff > .9) ? 1 : 0;
-  }
-  else
-    result = (((TreeMapItem*)item1)->text(textNo) <
-	      ((TreeMapItem*)item2)->text(textNo)) ? -1 : 1;
-
-  return ascending ? result : -result;
-}
-
 
 TreeMapItem* TreeMapItemList::commonParent()
 {
-  TreeMapItem* parent, *item;
-  parent = first();
-  if (parent)
-    while( (item = next()) != 0)
-      parent = parent->commonParent(item);
+  if (isEmpty()) return 0;
+
+  TreeMapItem* parent = first();
+  for(int i = 1; parent && i<size(); i++)
+      parent = parent->commonParent(at(i));
 
   return parent;
 }
 
+class TreeMapItemLessThan
+{
+public:
+    bool operator()(const TreeMapItem* i1, const TreeMapItem* i2) const
+    {
+	TreeMapItem* p = i1->parent();
+	// should not happen
+	if (!p) return false;
+
+	bool ascending;
+	bool result;
+	int textNo = p->sorting(&ascending);
+	if (textNo < 0)
+	    result = i1->value() < i2->value();
+	else
+	    result = i1->text(textNo) < i2->text(textNo);
+
+	return ascending ? result : !result;
+    }
+};
+
+TreeMapItemLessThan treeMapItemLessThan;
 
 // TreeMapItem
 
@@ -841,7 +841,6 @@ TreeMapItem::TreeMapItem(TreeMapItem* parent, double value)
   _index = -1;
   _depth = -1; // not set
   _unused_self = 0;
-  _freeRects = 0;
 
   if (_parent) {
     // take sorting from parent
@@ -874,15 +873,17 @@ TreeMapItem::TreeMapItem(TreeMapItem* parent, double value,
   _index = -1;
   _depth = -1; // not set
   _unused_self = 0;
-  _freeRects = 0;
 
   if (_parent) _parent->addItem(this);
 }
 
 TreeMapItem::~TreeMapItem()
 {
-  if (_children) delete _children;
-  if (_freeRects) delete _freeRects;
+    if (_children) {
+	qDeleteAll(*_children);
+	delete _children;
+	_children = 0;
+    }
 
   // finally, notify widget about deletion
   if (_widget) _widget->deletingItem(this);
@@ -926,6 +927,7 @@ void TreeMapItem::clear()
     // delete selected items below this item from selection
     if (_widget) _widget->clearSelection(this);
 
+    qDeleteAll(*_children);
     delete _children;
     _children = 0;
   }
@@ -969,7 +971,6 @@ bool TreeMapItem::initialized()
 {
   if (!_children) {
     _children = new TreeMapItemList;
-    _children->setAutoDelete(true);
     return false;
   }
   return true;
@@ -979,16 +980,14 @@ void TreeMapItem::addItem(TreeMapItem* i)
 {
   if (!i) return;
 
-  if (!_children) {
+  if (!_children)
     _children = new TreeMapItemList;
-    _children->setAutoDelete(true);
-  }
+
   i->setParent(this);
 
-  if (sorting(0) == -1)
-    _children->append(i); // preserve insertion order
-  else
-    _children->inSort(i);
+  _children->append(i); // preserve insertion order
+  if (sorting(0) != -1)
+    qSort(_children->begin(), _children->end(), treeMapItemLessThan);
 }
 
 
@@ -1054,17 +1053,19 @@ void TreeMapItem::setSorting(int textNo, bool ascending)
     _sortAscending = ascending;
     _sortTextNo = textNo;
 
-    if (_children && _sortTextNo != -1) _children->sort();
+    if (_children && _sortTextNo != -1)
+	qSort(_children->begin(), _children->end(), treeMapItemLessThan);
 }
 
 void TreeMapItem::resort(bool recursive)
 {
   if (!_children) return;
 
-  if (_sortTextNo != -1) _children->sort();
+  if (_sortTextNo != -1)
+      qSort(_children->begin(), _children->end(), treeMapItemLessThan);
 
   if (recursive)
-    for (TreeMapItem* i=_children->first(); i; i=_children->next())
+    foreach(TreeMapItem* i, *_children)
       i->resort(recursive);
 }
 
@@ -1084,10 +1085,9 @@ int TreeMapItem::rtti() const
 
 TreeMapItemList* TreeMapItem::children()
 {
-  if (!_children) {
+  if (!_children)
     _children = new TreeMapItemList;
-    _children->setAutoDelete(true);
-  }
+
   return _children;
 }
 
@@ -1099,7 +1099,7 @@ void TreeMapItem::clearItemRect()
 
 void TreeMapItem::clearFreeRects()
 {
-    if (_freeRects) _freeRects->clear();
+    _freeRects.clear();
 }
 
 void TreeMapItem::addFreeRect(const QRect& r)
@@ -1107,46 +1107,40 @@ void TreeMapItem::addFreeRect(const QRect& r)
     // do not add invalid rects
     if ((r.width() < 1) || (r.height() < 1)) return;
 
-    if (!_freeRects) {
-	_freeRects = new Q3PtrList<QRect>;
-	_freeRects->setAutoDelete(true);
-    }
-
     if (0) qDebug() << "addFree(" << path(0).join("/") << ", "
 		     << r.x() << "/" << r.y() << "-"
 		     << r.width() << "x" << r.height() << ")";
 
-    QRect* last = _freeRects->last();
-    if (!last) {
-	_freeRects->append(new QRect(r));
+    if (_freeRects.isEmpty()) {
+	_freeRects.append(r);
 	return;
     }
 
     // join rect with last rect if possible
     // this saves memory and does not make the tooltip flicker
-
+    QRect& last = _freeRects.last();
     bool replaced = false;
-    if ((last->left() == r.left()) && (last->width() == r.width())) {
-	if ((last->bottom()+1 == r.top()) || (r.bottom()+1 == last->top())) {
-	    *last |= r;
+    if ((last.left() == r.left()) && (last.width() == r.width())) {
+	if ((last.bottom()+1 == r.top()) || (r.bottom()+1 == last.top())) {
+	    last |= r;
 	    replaced = true;
 	}
     }
-    else if ((last->top() == r.top()) && (last->height() == r.height())) {
-	if ((last->right()+1 == r.left()) || (r.right()+1 == last->left())) {
-	    *last |= r;
+    else if ((last.top() == r.top()) && (last.height() == r.height())) {
+	if ((last.right()+1 == r.left()) || (r.right()+1 == last.left())) {
+	    last |= r;
 	    replaced = true;
 	}
     }
 
     if (!replaced) {
-	_freeRects->append(new QRect(r));
+	_freeRects.append(r);
 	return;
     }
 
     if (0) qDebug() << "  united with last to ("
-		     << last->x() << "/" << last->y() << "-"
-		     << last->width() << "x" << last->height() << ")";
+		     << last.x() << "/" << last.y() << "-"
+		     << last.width() << "x" << last.height() << ")";
 }
 
 
@@ -1197,13 +1191,11 @@ TreeMapWidget::TreeMapWidget(TreeMapItem* base,
 
   setAttribute(Qt::WA_NoSystemBackground, true);
   setFocusPolicy(Qt::StrongFocus);
-  //_tip = new TreeMapTip(this);
 }
 
 TreeMapWidget::~TreeMapWidget()
 {
   delete _base;
-  //delete _tip;
 }
 
 const QFont& TreeMapWidget::currentFont() const
@@ -1506,11 +1498,8 @@ void TreeMapWidget::setMinimalArea(int area)
 void TreeMapWidget::deletingItem(TreeMapItem* i)
 {
   // remove any references to the item to be deleted
-  while(_selection.findRef(i) > -1)
-    _selection.remove();
-
-  while(_tmpSelection.findRef(i) > -1)
-    _tmpSelection.remove();
+  _selection.removeAll(i);
+  _tmpSelection.removeAll(i);
 
   if (_current == i) _current = 0;
   if (_oldCurrent == i) _oldCurrent = 0;
@@ -1548,19 +1537,19 @@ QString TreeMapWidget::tipString(TreeMapItem* i) const
 
 TreeMapItem* TreeMapWidget::item(int x, int y) const
 {
-  TreeMapItem* p = _base;
-  TreeMapItem* i;
 
   if (!rect().contains(x, y)) return 0;
   if (DEBUG_DRAWING) qDebug() << "item(" << x << "," << y << "):";
 
+  TreeMapItem* p = _base;
+  TreeMapItem* i;
   while (1) {
     TreeMapItemList* list = p->children();
-    if (!list)
-      i = 0;
-    else {
-      int idx=0;
-      for (i=list->first();i;i=list->next(),idx++) {
+    i = 0;
+    if (list) {
+      int idx;
+      for (idx=0; idx<list->size(); idx++) {
+	i = list->at(idx);
 
         if (DEBUG_DRAWING)
 	    qDebug() << "  Checking " << i->path(0).join("/") << " ("
@@ -1576,6 +1565,7 @@ TreeMapItem* TreeMapWidget::item(int x, int y) const
 	    break;
         }
       }
+      if (idx == list->size()) i = 0; // not contained in child
     }
 
     if (!i) {
@@ -1619,7 +1609,7 @@ TreeMapItem* TreeMapWidget::visibleItem(TreeMapItem* i) const
                 (i->itemRect().height() <1))) {
       TreeMapItem* p = i->parent();
       if (!p) break;
-      int idx = p->children()->findRef(i);
+      int idx = p->children()->indexOf(i);
       idx--;
       if (idx<0)
         i = p;
@@ -1665,19 +1655,14 @@ TreeMapItemList TreeMapWidget::diff(TreeMapItemList& l1,
 				    TreeMapItemList& l2)
 {
   TreeMapItemList l;
-  TreeMapItemListIterator it1(l1), it2(l2);
 
-  TreeMapItem* item;
-  while ( (item = it1.current()) != 0 ) {
-    ++it1;
-    if (l2.containsRef(item) > 0) continue;
-    l.append(item);
-  }
-  while ( (item = it2.current()) != 0 ) {
-    ++it2;
-    if (l1.containsRef(item) > 0) continue;
-    l.append(item);
-  }
+  foreach(TreeMapItem* i, l1)
+    if (!l2.contains(i))
+      l.append(i);
+
+  foreach(TreeMapItem* i, l2)
+    if (!l1.contains(i))
+      l.append(i);
 
   return l;
 }
@@ -1699,19 +1684,15 @@ TreeMapItem* TreeMapWidget::setTmpSelected(TreeMapItem* item, bool selected)
   }
   else {
     if (selected) {
-      TreeMapItem* i=_tmpSelection.first();
-      while (i) {
-	if (i->isChildOf(item) || item->isChildOf(i)) {
-	  _tmpSelection.remove();
-	  i = _tmpSelection.current();
-	}
-	else
-	  i = _tmpSelection.next();
-      }
-      _tmpSelection.append(item);
+	// first remove any selection which is parent or child of <item>
+	foreach(TreeMapItem* i, _tmpSelection)
+	    if (i->isChildOf(item) || item->isChildOf(i))
+		_tmpSelection.removeAll(i);
+
+	_tmpSelection.append(item);
     }
     else
-      _tmpSelection.removeRef(item);
+      _tmpSelection.removeAll(item);
   }
 
   return diff(old, _tmpSelection).commonParent();
@@ -1722,15 +1703,10 @@ bool TreeMapWidget::clearSelection(TreeMapItem* parent)
 {
   TreeMapItemList old = _selection;
 
-  TreeMapItem* i=_selection.first();
-  while (i) {
-    if (i->isChildOf(parent)) {
-      _selection.remove();
-      i = _selection.current();
-    }
-    else
-      i = _selection.next();
-  }
+  // remove any selection which is child of <parent>
+  foreach(TreeMapItem* i, _selection)
+      if (i->isChildOf(parent))
+	  _selection.removeAll(i);
 
   TreeMapItem* changed = diff(old, _selection).commonParent();
   if (changed) {
@@ -1743,13 +1719,13 @@ bool TreeMapWidget::clearSelection(TreeMapItem* parent)
 bool TreeMapWidget::isSelected(TreeMapItem* i) const
 {
     if (!i) return false;
-    return _selection.containsRef(i)>0;
+    return _selection.contains(i);
 }
 
 bool TreeMapWidget::isTmpSelected(TreeMapItem* i)
 {
     if (!i) return false;
-    return _tmpSelection.containsRef(i)>0;
+    return _tmpSelection.contains(i);
 }
 
 
@@ -1824,9 +1800,8 @@ TreeMapItem* TreeMapWidget::setTmpRangeSelection(TreeMapItem* i1,
   TreeMapItemList* list = commonParent->children();
   if (!list) return changed;
 
-  TreeMapItem* i = list->first();
   bool between = false;
-  while (i) {
+  foreach(TreeMapItem* i, *list) {
     if (between) {
       if (i==i1 || i==i2) break;
       changed2 = setTmpSelected(i, selected);
@@ -1834,7 +1809,6 @@ TreeMapItem* TreeMapWidget::setTmpRangeSelection(TreeMapItem* i1,
     }
     else if (i==i1 || i==i2)
       between = true;
-    i = list->next();
   }
 
   return changed;
@@ -2014,7 +1988,7 @@ int nextVisible(TreeMapItem* i)
   TreeMapItem* p = i->parent();
   if (!p || p->itemRect().isEmpty()) return -1;
 
-  int idx = p->children()->findRef(i);
+  int idx = p->children()->indexOf(i);
   if (idx<0) return -1;
 
   while (idx < (int)p->children()->count()-1) {
@@ -2032,7 +2006,7 @@ int prevVisible(TreeMapItem* i)
   TreeMapItem* p = i->parent();
   if (!p || p->itemRect().isEmpty()) return -1;
 
-  int idx = p->children()->findRef(i);
+  int idx = p->children()->indexOf(i);
   if (idx<0) return -1;
 
   while (idx > 0) {
@@ -2169,25 +2143,25 @@ void TreeMapWidget::fontChange( const QFont& )
 // react on tooltip events
 bool TreeMapWidget::event(QEvent *event)
 {
-	if (event->type() == QEvent::ToolTip) {
-		QHelpEvent *helpEvent = static_cast<QHelpEvent *>(event);
-		TreeMapItem* i = item(helpEvent->pos().x(), helpEvent->pos().y());
-		Q3PtrList<QRect>* rList = i ? i->freeRects() : 0;
-		bool hasTip = false;
-		if (rList) {
-			QRect* r;
-			for (r=rList->first(); r; r=rList->next())
-				if (r->contains(helpEvent->pos())) {
-					hasTip = true;
-					break;
-				}
+    if (event->type() == QEvent::ToolTip) {
+	QHelpEvent *helpEvent = static_cast<QHelpEvent *>(event);
+	TreeMapItem* i = item(helpEvent->pos().x(), helpEvent->pos().y());
+	bool hasTip = false;
+	if (i) {
+	    const QList<QRect>& rList = i->freeRects();
+	    foreach(const QRect& r, rList) {
+		if (r.contains(helpEvent->pos())) {
+		    hasTip = true;
+		    break;
 		}
-		if (hasTip)
-			QToolTip::showText(helpEvent->globalPos(), tipString(i));
-		else
-			QToolTip::hideText();
+	    }
 	}
-	return QWidget::event(event);
+	if (hasTip)
+	    QToolTip::showText(helpEvent->globalPos(), tipString(i));
+	else
+	    QToolTip::hideText();
+    }
+    return QWidget::event(event);
 }
 
 void TreeMapWidget::paintEvent( QPaintEvent * )
@@ -2235,15 +2209,15 @@ void TreeMapWidget::drawTreeMap()
   }
 
   bitBlt( this, 0, 0, &_pixmap, 0, 0,
-          QWidget::width(), QWidget::height()); //, CopyROP, true);
+	  QWidget::width(), QWidget::height());
 
   if (hasFocus()) {
-    QPainter p(this);
-#if 0
-    style().drawPrimitive( QStyle::PE_FocusRect, &p,
-                           QRect(0, 0, QWidget::width(), QWidget::height()),
-                           colorGroup() );
-#endif
+    QStylePainter p(this);
+    QStyleOptionFocusRect opt;
+    opt.rect = rect();
+    opt.palette = palette();
+    opt.state = QStyle::State_None;
+    p.drawPrimitive( QStyle::PE_FrameFocusRect, opt );
   }
 }
 
@@ -2269,32 +2243,35 @@ void TreeMapWidget::redraw(TreeMapItem* i)
 void TreeMapWidget::drawItem(QPainter* p,
                              TreeMapItem* item)
 {
-  bool isSelected = false;
-  TreeMapItem* i;
+    bool isSelected = false;
 
-  if (_markNo>0) {
-      for(i = item;i;i=i->parent())
-	  if (i->isMarked(_markNo)) break;
+    if (_markNo>0) {
+	for(TreeMapItem* i = item; i; i=i->parent()) {
+	    if (i->isMarked(_markNo)) {
+		isSelected = true;
+		break;
+	    }
+	}
+    }
+    else {
+	foreach(TreeMapItem* i, _tmpSelection) {
+	    if (item->isChildOf(i)) {
+		isSelected = true;
+		break;
+	    }
+	}
+    }
 
-      isSelected = (i!=0);
-  }
-  else {
-      for (i=_tmpSelection.first();i;i=_tmpSelection.next())
-	  if (item->isChildOf(i)) break;
+    bool isCurrent = _current && item->isChildOf(_current);
+    int dd = item->depth();
+    if (isTransparent(dd)) return;
 
-      isSelected = (i!=0);
-  }
-
-  bool isCurrent = _current && item->isChildOf(_current);
-  int dd = item->depth();
-  if (isTransparent(dd)) return;
-
-  RectDrawing d(item->itemRect());
-  item->setSelected(isSelected);
-  item->setCurrent(isCurrent);
-  item->setShaded(_shading);
-  item->drawFrame(drawFrame(dd));
-  d.drawBack(p, item);
+    RectDrawing d(item->itemRect());
+    item->setSelected(isSelected);
+    item->setCurrent(isCurrent);
+    item->setShaded(_shading);
+    item->drawFrame(drawFrame(dd));
+    d.drawBack(p, item);
 }
 
 
@@ -2338,7 +2315,6 @@ void TreeMapWidget::drawItems(QPainter* p,
                   origRect.width()-2*bw, origRect.height()-2*bw);
 
   TreeMapItemList* list = item->children();
-  TreeMapItem* i;
 
   bool stopDrawing = false;
 
@@ -2376,7 +2352,7 @@ void TreeMapWidget::drawItems(QPainter* p,
   if (stopDrawing) {
     if (list) {
       // invalidate rects
-      for (i=list->first();i;i=list->next())
+      foreach(TreeMapItem* i, *list)
         i->clearItemRect();
     }
     // tooltip apears on whole item rect
@@ -2405,7 +2381,7 @@ void TreeMapWidget::drawItems(QPainter* p,
 
   // own sum
   child_sum = 0;
-  for (i=list->first();i;i=list->next()) {
+  foreach(TreeMapItem* i, *list) {
     child_sum += i->value();
     if (DEBUG_DRAWING)
       qDebug() << "  child: " << i->text(0) << ", value "
@@ -2519,15 +2495,14 @@ void TreeMapWidget::drawItems(QPainter* p,
     goBack = false;
   }
 
-  TreeMapItemListIterator it(*list);
-  if (goBack) it.toLast();
+  int idx = goBack ? (list->size()-1) : 0;
 
   if (item->splitMode() == TreeMapItem::Columns) {
     int len = list->count();
     bool drawDetails = true;
 
     while (len>0 && user_sum>0) {
-      TreeMapItemListIterator first = it;
+      int firstIdx = idx;
       double valSum = 0;
       int lenLeft = len;
       int columns = (int)(sqrt((double)len * r.width()/r.height())+.5);
@@ -2535,8 +2510,8 @@ void TreeMapWidget::drawItems(QPainter* p,
 
       while (lenLeft>0 && ((double)valSum*(len-lenLeft) <
                            (double)len*user_sum/columns/columns)) {
-        valSum += it.current()->value();
-        if (goBack) --it; else ++it;
+	valSum += list->at(idx)->value();
+	if (goBack) --idx; else ++idx;
         lenLeft--;
       }
 
@@ -2551,13 +2526,13 @@ void TreeMapWidget::drawItems(QPainter* p,
 	  }
 	  else {
 	      // fill rest with hash pattern
-	      drawFill(item, p, r, first, len, goBack);
+	      drawFill(item, p, r, list, firstIdx, len, goBack);
 	      break;
 	  }
       }
       else {
         drawDetails = drawItemArray(p, item, firstRect,
-                                    valSum, first, len-lenLeft, goBack);
+				    valSum, list, firstIdx, len-lenLeft, goBack);
       }
       r.setRect(r.x()+nextPos, r.y(), r.width()-nextPos, r.height());
       user_sum -= valSum;
@@ -2567,7 +2542,7 @@ void TreeMapWidget::drawItems(QPainter* p,
         if (item->sorting(0) == -1)
           drawDetails = true;
         else {
-          drawFill(item, p, r, it, len, goBack);
+	  drawFill(item, p, r, list, idx, len, goBack);
           break;
         }
       }
@@ -2578,7 +2553,7 @@ void TreeMapWidget::drawItems(QPainter* p,
     bool drawDetails = true;
 
     while (len>0 && user_sum>0) {
-      TreeMapItemListIterator first = it;
+      int firstIdx = idx;
       double valSum = 0;
       int lenLeft = len;
       int rows = (int)(sqrt((double)len * r.height()/r.width())+.5);
@@ -2586,8 +2561,8 @@ void TreeMapWidget::drawItems(QPainter* p,
 
       while (lenLeft>0 && ((double)valSum*(len-lenLeft) <
                            (double)len*user_sum/rows/rows)) {
-        valSum += it.current()->value();
-        if (goBack) --it; else ++it;
+	valSum += list->at(idx)->value();
+	if (goBack) --idx; else ++idx;
         lenLeft--;
       }
 
@@ -2600,13 +2575,13 @@ void TreeMapWidget::drawItems(QPainter* p,
 	    drawFill(item, p, firstRect);
         }
         else {
-	    drawFill(item, p, r, first, len, goBack);
+	    drawFill(item, p, r, list, firstIdx, len, goBack);
 	    break;
         }
       }
       else {
         drawDetails = drawItemArray(p, item, firstRect,
-                                    valSum, first, len-lenLeft, goBack);
+				    valSum, list, firstIdx, len-lenLeft, goBack);
       }
       r.setRect(r.x(), r.y()+nextPos, r.width(), r.height()-nextPos);
       user_sum -= valSum;
@@ -2616,14 +2591,14 @@ void TreeMapWidget::drawItems(QPainter* p,
         if (item->sorting(0) == -1)
           drawDetails = true;
         else {
-          drawFill(item, p, r, it, len, goBack);
+	  drawFill(item, p, r, list, idx, len, goBack);
           break;
         }
       }
     }
   }
   else
-    drawItemArray(p, item, r, user_sum, it, list->count(), goBack);
+    drawItemArray(p, item, r, user_sum, list, idx, list->count(), goBack);
 
   if (DEBUG_DRAWING)
       qDebug() << "-drawItems(" << item->path(0).join("/") << ")";
@@ -2640,7 +2615,7 @@ void TreeMapWidget::drawFill(TreeMapItem* i, QPainter* p, const QRect& r)
 
 // fills area with a pattern if to small to draw children
 void TreeMapWidget::drawFill(TreeMapItem* i, QPainter* p, const QRect& r,
-                             TreeMapItemListIterator it, int len, bool goBack)
+			     TreeMapItemList* list, int idx, int len, bool goBack)
 {
   if (DEBUG_DRAWING)
       qDebug() << "  +drawFill(" << r.x() << "/" << r.y()
@@ -2653,13 +2628,13 @@ void TreeMapWidget::drawFill(TreeMapItem* i, QPainter* p, const QRect& r,
   i->addFreeRect(r);
 
   // reset rects
-  while (len>0 && it.current()) {
+  while (len>0 && (i=list->value(idx))) {
 
       if (DEBUG_DRAWING)
-	  qDebug() << "   Reset Rect " << (*it)->path(0).join("/");
+	  qDebug() << "   Reset Rect " << i->path(0).join("/");
 
-      (*it)->clearItemRect();
-      if (goBack) --it; else ++it;
+      i->clearItemRect();
+      if (goBack) --idx; else ++idx;
       len--;
   }
   if (DEBUG_DRAWING)
@@ -2671,7 +2646,7 @@ void TreeMapWidget::drawFill(TreeMapItem* i, QPainter* p, const QRect& r,
 // returns false if rect gets to small
 bool TreeMapWidget::drawItemArray(QPainter* p, TreeMapItem* item,
                                   const QRect& r, double user_sum,
-                                  TreeMapItemListIterator it, int len,
+				  TreeMapItemList* list, int idx, int len,
 				  bool goBack)
 {
   if (user_sum == 0) return false;
@@ -2684,7 +2659,7 @@ bool TreeMapWidget::drawItemArray(QPainter* p, TreeMapItem* item,
       ((_minimalArea > 0) &&
        (r.width() * r.height() < _minimalArea))) {
 
-    drawFill(item, p, r, it, len, goBack);
+    drawFill(item, p, r, list, idx, len, goBack);
     return false;
   }
 
@@ -2695,13 +2670,13 @@ bool TreeMapWidget::drawItemArray(QPainter* p, TreeMapItem* item,
 
   if (len>2 && (item->splitMode() == TreeMapItem::Bisection)) {
 
-    TreeMapItemListIterator first = it;
+    int firstIdx = idx;
     double valSum = 0;
     int lenLeft = len;
     //while (lenLeft>0 && valSum<user_sum/2) {
     while (lenLeft>len/2) {
-      valSum += it.current()->value();
-      if (goBack) --it; else ++it;
+      valSum += list->at(idx)->value();
+      if (goBack) --idx; else ++idx;
       lenLeft--;
     }
 
@@ -2713,14 +2688,14 @@ bool TreeMapWidget::drawItemArray(QPainter* p, TreeMapItem* item,
       int halfPos = (int)((double)r.width() * valSum / user_sum);
       QRect firstRect = QRect(r.x(), r.y(), halfPos, r.height());
       drawOn = drawItemArray(p, item, firstRect,
-                             valSum, first, len-lenLeft, goBack);
+			     valSum, list, firstIdx, len-lenLeft, goBack);
       secondRect.setRect(r.x()+halfPos, r.y(), r.width()-halfPos, r.height());
     }
     else {
       int halfPos = (int)((double)r.height() * valSum / user_sum);
       QRect firstRect = QRect(r.x(), r.y(), r.width(), halfPos);
       drawOn = drawItemArray(p, item, firstRect,
-                             valSum, first, len-lenLeft, goBack);
+			     valSum, list, firstIdx, len-lenLeft, goBack);
       secondRect.setRect(r.x(), r.y()+halfPos, r.width(), r.height()-halfPos);
     }
 
@@ -2730,9 +2705,9 @@ bool TreeMapWidget::drawItemArray(QPainter* p, TreeMapItem* item,
     // second half
     if (drawOn)
       drawOn = drawItemArray(p, item, secondRect, user_sum - valSum,
-                             it, lenLeft, goBack);
+			     list, idx, lenLeft, goBack);
     else {
-      drawFill(item, p, secondRect, it, len, goBack);
+      drawFill(item, p, secondRect, list, idx, len, goBack);
     }
 
     if (DEBUG_DRAWING)
@@ -2747,14 +2722,14 @@ bool TreeMapWidget::drawItemArray(QPainter* p, TreeMapItem* item,
   TreeMapItem* i;
   QRect fullRect = r;
   while (len>0) {
-    i = it.current();
+    i = list->at(idx);
     if (user_sum <= 0) {
 
       if (DEBUG_DRAWING)
 	  qDebug() << "drawItemArray: Reset " << i->path(0).join("/");
 
       i->clearItemRect();
-      if (goBack) --it; else ++it;
+      if (goBack) --idx; else ++idx;
       len--;
       continue;
     }
@@ -2765,7 +2740,7 @@ bool TreeMapWidget::drawItemArray(QPainter* p, TreeMapItem* item,
         ((_minimalArea > 0) &&
          (fullRect.width() * fullRect.height() < _minimalArea))) {
 
-      drawFill(item, p, fullRect, it, len, goBack);
+      drawFill(item, p, fullRect, list, idx, len, goBack);
       if (DEBUG_DRAWING)
 	  qDebug() << " -drawItemArray(" << item->path(0).join("/")
 		    << "): Stop";
@@ -2781,7 +2756,7 @@ bool TreeMapWidget::drawItemArray(QPainter* p, TreeMapItem* item,
     if (nextPos>lastPos) nextPos = lastPos;
 
     if ((item->sorting(0) != -1) && (nextPos < _visibleWidth)) {
-      drawFill(item, p, fullRect, it, len, goBack);
+      drawFill(item, p, fullRect, list, idx, len, goBack);
       if (DEBUG_DRAWING)
 	  qDebug() << " -drawItemArray(" << item->path(0).join("/")
 		    << "): Stop";
@@ -2836,7 +2811,7 @@ bool TreeMapWidget::drawItemArray(QPainter* p, TreeMapItem* item,
     }
 
     user_sum -= val;
-    if (goBack) --it; else ++it;
+    if (goBack) --idx; else ++idx;
     len--;
   }
 
@@ -2852,346 +2827,33 @@ bool TreeMapWidget::drawItemArray(QPainter* p, TreeMapItem* item,
  * Popup menus for option setting
  */
 
-void TreeMapWidget::splitActivated(int id)
+void TreeMapWidget::splitActivated(QAction* a)
 {
-  if      (id == _splitID)   setSplitMode(TreeMapItem::Bisection);
-  else if (id == _splitID+1) setSplitMode(TreeMapItem::Columns);
-  else if (id == _splitID+2) setSplitMode(TreeMapItem::Rows);
-  else if (id == _splitID+3) setSplitMode(TreeMapItem::AlwaysBest);
-  else if (id == _splitID+4) setSplitMode(TreeMapItem::Best);
-  else if (id == _splitID+5) setSplitMode(TreeMapItem::VAlternate);
-  else if (id == _splitID+6) setSplitMode(TreeMapItem::HAlternate);
-  else if (id == _splitID+7) setSplitMode(TreeMapItem::Horizontal);
-  else if (id == _splitID+8) setSplitMode(TreeMapItem::Vertical);
+    setSplitMode( (TreeMapItem::SplitMode) a->data().toInt());
 }
 
-
-void TreeMapWidget::addSplitDirectionItems(Q3PopupMenu* popup, int id)
+void TreeMapWidget::addSplitAction(QMenu* m, const QString& s, int v)
 {
-  _splitID = id;
-  popup->setCheckable(true);
-
-  connect(popup, SIGNAL(activated(int)),
-          this, SLOT(splitActivated(int)));
-
-  popup->insertItem(tr("Recursive Bisection"), id);
-  popup->insertItem(tr("Columns"),         id+1);
-  popup->insertItem(tr("Rows"),            id+2);
-  popup->insertItem(tr("Always Best"),     id+3);
-  popup->insertItem(tr("Best"),            id+4);
-  popup->insertItem(tr("Alternate (V)"),   id+5);
-  popup->insertItem(tr("Alternate (H)"),   id+6);
-  popup->insertItem(tr("Horizontal"),      id+7);
-  popup->insertItem(tr("Vertical"),        id+8);
-
-  switch(splitMode()) {
-    case TreeMapItem::Bisection:  popup->setItemChecked(id,true); break;
-    case TreeMapItem::Columns:    popup->setItemChecked(id+1,true); break;
-    case TreeMapItem::Rows:       popup->setItemChecked(id+2,true); break;
-    case TreeMapItem::AlwaysBest: popup->setItemChecked(id+3,true); break;
-    case TreeMapItem::Best:       popup->setItemChecked(id+4,true); break;
-    case TreeMapItem::VAlternate: popup->setItemChecked(id+5,true); break;
-    case TreeMapItem::HAlternate: popup->setItemChecked(id+6,true); break;
-    case TreeMapItem::Horizontal: popup->setItemChecked(id+7,true); break;
-    case TreeMapItem::Vertical:   popup->setItemChecked(id+8,true); break;
-    default: break;
-  }
+    QAction* a = m->addAction(s);
+    a->setData(v);
+    a->setCheckable(true);
+    a->setChecked(splitMode() == v);
 }
 
-void TreeMapWidget::visualizationActivated(int id)
+void TreeMapWidget::addSplitDirectionItems(QMenu* m)
 {
-  if (id == _visID+2) setSkipIncorrectBorder(!skipIncorrectBorder());
-  else if (id == _visID+3) setBorderWidth(0);
-  else if (id == _visID+4) setBorderWidth(1);
-  else if (id == _visID+5) setBorderWidth(2);
-  else if (id == _visID+6) setBorderWidth(3);
-  else if (id == _visID+10) setAllowRotation(!allowRotation());
-  else if (id == _visID+11) setShadingEnabled(!isShadingEnabled());
-  else if (id<_visID+19 || id>_visID+100) return;
+    connect(m, SIGNAL(triggered(QAction*)),
+	    this, SLOT(splitActivated(QAction*)) );
 
-  id -= 20+_visID;
-  int f = id/10;
-  if      ((id%10) == 1) setFieldVisible(f, !fieldVisible(f));
-  else if ((id%10) == 2) setFieldForced(f, !fieldForced(f));
-  else if ((id%10) == 3) setFieldPosition(f, DrawParams::TopLeft);
-  else if ((id%10) == 4) setFieldPosition(f, DrawParams::TopCenter);
-  else if ((id%10) == 5) setFieldPosition(f, DrawParams::TopRight);
-  else if ((id%10) == 6) setFieldPosition(f, DrawParams::BottomLeft);
-  else if ((id%10) == 7) setFieldPosition(f, DrawParams::BottomCenter);
-  else if ((id%10) == 8) setFieldPosition(f, DrawParams::BottomRight);
-}
-
-void TreeMapWidget::addVisualizationItems(Q3PopupMenu* popup, int id)
-{
-  _visID = id;
-
-  popup->setCheckable(true);
-
-  Q3PopupMenu* bpopup = new Q3PopupMenu();
-  bpopup->setCheckable(true);
-
-  connect(popup, SIGNAL(activated(int)),
-          this, SLOT(visualizationActivated(int)));
-  connect(bpopup, SIGNAL(activated(int)),
-          this, SLOT(visualizationActivated(int)));
-
-  Q3PopupMenu* spopup = new Q3PopupMenu();
-  addSplitDirectionItems(spopup, id+100);
-  popup->insertItem(tr("Nesting"), spopup, id);
-
-  popup->insertItem(tr("Border"), bpopup, id+1);
-  bpopup->insertItem(tr("Correct Borders Only"), id+2);
-  bpopup->addSeparator();
-  bpopup->insertItem(tr("Width %1").arg(0), id+3);
-  bpopup->insertItem(tr("Width %1").arg(1), id+4);
-  bpopup->insertItem(tr("Width %1").arg(2), id+5);
-  bpopup->insertItem(tr("Width %1").arg(3), id+6);
-  bpopup->setItemChecked(id+2, skipIncorrectBorder());
-  bpopup->setItemChecked(id+3, borderWidth()==0);
-  bpopup->setItemChecked(id+4, borderWidth()==1);
-  bpopup->setItemChecked(id+5, borderWidth()==2);
-  bpopup->setItemChecked(id+6, borderWidth()==3);
-
-  popup->insertItem(tr("Allow Rotation"), id+10);
-  popup->setItemChecked(id+10,allowRotation());
-  popup->insertItem(tr("Shading"), id+11);
-  popup->setItemChecked(id+11,isShadingEnabled());
-
-  if (_attr.size() ==0) return;
-
-  popup->addSeparator();
-  int f;
-  Q3PopupMenu* tpopup;
-  id += 20;
-  for (f=0;f<(int)_attr.size();f++, id+=10) {
-    tpopup = new Q3PopupMenu();
-    tpopup->setCheckable(true);
-    popup->insertItem(_attr[f].type, tpopup, id);
-    tpopup->insertItem(tr("Visible"), id+1);
-    tpopup->insertItem(tr("Take Space From Children"), id+2);
-    tpopup->addSeparator();
-    tpopup->insertItem(tr("Top Left"), id+3);
-    tpopup->insertItem(tr("Top Center"), id+4);
-    tpopup->insertItem(tr("Top Right"), id+5);
-    tpopup->insertItem(tr("Bottom Left"), id+6);
-    tpopup->insertItem(tr("Bottom Center"), id+7);
-    tpopup->insertItem(tr("Bottom Right"), id+8);
-
-    tpopup->setItemChecked(id+1,_attr[f].visible);
-    tpopup->setItemEnabled(id+2,_attr[f].visible);
-    tpopup->setItemEnabled(id+3,_attr[f].visible);
-    tpopup->setItemEnabled(id+4,_attr[f].visible);
-    tpopup->setItemEnabled(id+5,_attr[f].visible);
-    tpopup->setItemEnabled(id+6,_attr[f].visible);
-    tpopup->setItemEnabled(id+7,_attr[f].visible);
-    tpopup->setItemEnabled(id+8,_attr[f].visible);
-    tpopup->setItemChecked(id+2,_attr[f].forced);
-    tpopup->setItemChecked(id+3,_attr[f].pos == DrawParams::TopLeft);
-    tpopup->setItemChecked(id+4,_attr[f].pos == DrawParams::TopCenter);
-    tpopup->setItemChecked(id+5,_attr[f].pos == DrawParams::TopRight);
-    tpopup->setItemChecked(id+6,_attr[f].pos == DrawParams::BottomLeft);
-    tpopup->setItemChecked(id+7,_attr[f].pos == DrawParams::BottomCenter);
-    tpopup->setItemChecked(id+8,_attr[f].pos == DrawParams::BottomRight);
-
-    connect(tpopup, SIGNAL(activated(int)),
-            this, SLOT(visualizationActivated(int)));
-  }
-}
-
-void TreeMapWidget::selectionActivated(int id)
-{
-  TreeMapItem* i = _menuItem;
-  id -= _selectionID;
-  while (id>0 && i) {
-    i=i->parent();
-    id--;
-  }
-  if (i)
-    setSelected(i, true);
-}
-
-void TreeMapWidget::addSelectionItems(Q3PopupMenu* popup,
-				      int id, TreeMapItem* i)
-{
-  if (!i) return;
-
-  _selectionID = id;
-  _menuItem = i;
-
-  connect(popup, SIGNAL(activated(int)),
-          this, SLOT(selectionActivated(int)));
-
-  while (i) {
-    QString name = i->text(0);
-    if (name.isEmpty()) break;
-    popup->insertItem(i->text(0), id++);
-    i = i->parent();
-  }
-}
-
-void TreeMapWidget::fieldStopActivated(int id)
-{
-  if (id == _fieldStopID) setFieldStop(0, QString());
-  else {
-    TreeMapItem* i = _menuItem;
-    id -= _fieldStopID+1;
-    while (id>0 && i) {
-      i=i->parent();
-      id--;
-    }
-    if (i)
-      setFieldStop(0, i->text(0));
-  }
-}
-
-void TreeMapWidget::addFieldStopItems(Q3PopupMenu* popup,
-				      int id, TreeMapItem* i)
-{
-  _fieldStopID = id;
-
-  connect(popup, SIGNAL(activated(int)),
-          this, SLOT(fieldStopActivated(int)));
-
-  popup->insertItem(tr("No %1 Limit").arg(fieldType(0)), id);
-  popup->setItemChecked(id, fieldStop(0).isEmpty());
-  _menuItem = i;
-  bool foundFieldStop = false;
-  if (i) {
-    popup->addSeparator();
-
-    while (i) {
-      id++;
-      QString name = i->text(0);
-      if (name.isEmpty()) break;
-      popup->insertItem(i->text(0), id);
-      if (fieldStop(0) == i->text(0)) {
-        popup->setItemChecked(id, true);
-        foundFieldStop = true;
-      }
-      i = i->parent();
-    }
-  }
-
-  if (!foundFieldStop && !fieldStop(0).isEmpty()) {
-    popup->addSeparator();
-    popup->insertItem(fieldStop(0), id+1);
-    popup->setItemChecked(id+1, true);
-  }
-}
-
-void TreeMapWidget::areaStopActivated(int id)
-{
-  if (id == _areaStopID) setMinimalArea(-1);
-  else if (id == _areaStopID+1) {
-    int area = _menuItem ? (_menuItem->width() * _menuItem->height()) : -1;
-    setMinimalArea(area);
-  }
-  else if (id == _areaStopID+2) setMinimalArea(100);
-  else if (id == _areaStopID+3) setMinimalArea(400);
-  else if (id == _areaStopID+4) setMinimalArea(1000);
-  else if (id == _areaStopID+5) setMinimalArea(minimalArea()*2);
-  else if (id == _areaStopID+6) setMinimalArea(minimalArea()/2);
-}
-
-void TreeMapWidget::addAreaStopItems(Q3PopupMenu* popup,
-				     int id, TreeMapItem* i)
-{
-  _areaStopID = id;
-  _menuItem = i;
-
-  connect(popup, SIGNAL(activated(int)),
-          this, SLOT(areaStopActivated(int)));
-
-  bool foundArea = false;
-
-  popup->insertItem(tr("No Area Limit"), id);
-  popup->setItemChecked(id, minimalArea() == -1);
-
-  if (i) {
-    int area = i->width() * i->height();
-    popup->addSeparator();
-    popup->insertItem(tr("Area of '%1' (%2)")
-		      .arg(i->text(0)).arg(area), id+1);
-    if (area == minimalArea()) {
-      popup->setItemChecked(id+1, true);
-      foundArea = true;
-    }
-  }
-
-  popup->addSeparator();
-  int area = 100, count;
-  for (count=0;count<3;count++) {
-    popup->insertItem(tr("%n Pixel(s)", "", area), id+2+count);
-    if (area == minimalArea()) {
-      popup->setItemChecked(id+2+count, true);
-      foundArea = true;
-    }
-    area = (area==100) ? 400 : (area==400) ? 1000 : 4000;
-  }
-
-  if (minimalArea()>0) {
-    popup->addSeparator();
-    if (!foundArea) {
-      popup->insertItem(tr("%n Pixel(s)", "", minimalArea()), id+10);
-      popup->setItemChecked(id+10, true);
-    }
-
-    popup->insertItem(tr("Double Area Limit (to %1)")
-		      .arg(minimalArea()*2), id+5);
-    popup->insertItem(tr("Halve Area Limit (to %1)")
-		      .arg(minimalArea()/2), id+6);
-  }
-}
-
-
-void TreeMapWidget::depthStopActivated(int id)
-{
-  if (id == _depthStopID) setMaxDrawingDepth(-1);
-  else if (id == _depthStopID+1) {
-    int d = _menuItem ? _menuItem->depth() : -1;
-    setMaxDrawingDepth(d);
-  }
-  else if (id == _depthStopID+2) setMaxDrawingDepth(maxDrawingDepth()-1);
-  else if (id == _depthStopID+3) setMaxDrawingDepth(maxDrawingDepth()+1);
-}
-
-void TreeMapWidget::addDepthStopItems(Q3PopupMenu* popup,
-				      int id, TreeMapItem* i)
-{
-  _depthStopID = id;
-  _menuItem = i;
-
-  connect(popup, SIGNAL(activated(int)),
-          this, SLOT(depthStopActivated(int)));
-
-  bool foundDepth = false;
-
-  popup->insertItem(tr("No Depth Limit"), id);
-  popup->setItemChecked(id, maxDrawingDepth() == -1);
-
-  if (i) {
-    int d = i->depth();
-    popup->addSeparator();
-    popup->insertItem(tr("Depth of '%1' (%2)")
-		      .arg(i->text(0)).arg(d), id+1);
-    if (d == maxDrawingDepth()) {
-      popup->setItemChecked(id+1, true);
-      foundDepth = true;
-    }
-  }
-
-  if (maxDrawingDepth()>1) {
-    popup->addSeparator();
-    if (!foundDepth) {
-	popup->insertItem(tr("Depth %1").arg(maxDrawingDepth()), id+10);
-      popup->setItemChecked(id+10, true);
-    }
-
-    popup->insertItem(tr("Decrement (to %1)")
-		      .arg(maxDrawingDepth()-1), id+2);
-    popup->insertItem(tr("Increment (to %1)")
-		      .arg(maxDrawingDepth()+1), id+3);
-  }
+    addSplitAction(m, tr("Recursive Bisection"), TreeMapItem::Bisection);
+    addSplitAction(m, tr("Columns"), TreeMapItem::Columns);
+    addSplitAction(m, tr("Rows"), TreeMapItem::Rows);
+    addSplitAction(m, tr("Always Best"), TreeMapItem::AlwaysBest);
+    addSplitAction(m, tr("Best"), TreeMapItem::Best);
+    addSplitAction(m, tr("Alternate (V)"), TreeMapItem::VAlternate);
+    addSplitAction(m, tr("Alternate (H)"), TreeMapItem::HAlternate);
+    addSplitAction(m, tr("Horizontal"), TreeMapItem::Horizontal);
+    addSplitAction(m, tr("Vertical"), TreeMapItem::Vertical);
 }
 
 
