@@ -30,17 +30,13 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "version.h"
 #include "prefs_lokalize.h"
 
+#include "diff.h"
+
 #include <QProcess>
 #include <QString>
 #include <QMap>
 
 #include <kdebug.h>
-#include <kglobal.h>
-#include <klocale.h>
-#include <kdatetime.h>
-
-#include <kio/netaccess.h>
-#include <ktemporaryfile.h>
 
 // static QString GNUPluralForms(const QString& lang);
 
@@ -49,13 +45,6 @@ using namespace GettextCatalog;
 GettextStorage::GettextStorage()
  : CatalogStorage()
 {
-//     QStringList langlist (KGlobal::locale()->allLanguagesList());
-//     for (QStringList::const_iterator it=langlist.begin();it!=langlist.end();++it)
-//     {
-//         QString a=GNUPluralForms(*it);
-//         if (!a.isEmpty())
-//             kWarning()<<*it<<a;
-//     }
 }
 
 
@@ -65,17 +54,13 @@ GettextStorage::~GettextStorage()
 
 //BEGIN OPEN/SAVE
 
-bool GettextStorage::load(const KUrl& url)
+int GettextStorage::load(QIODevice* device/*, bool readonly*/)
 {
+    //GettextImportPlugin importer=GettextImportPlugin(readonly?(new ExtraDataSaver()):(new ExtraDataListSaver()));
     GettextImportPlugin importer;
     ConversionStatus status = OK;
-    QString target;
-
-    if(KDE_ISUNLIKELY( !KIO::NetAccess::download(url,target,NULL) ))
-        return false;
-
-    status = importer.open(target,this);
-    KIO::NetAccess::removeTempFile( target );
+    int errorLine;
+    status = importer.open(device,this,&errorLine);
 
     //for langs with more than 2 forms
     //we create any form-entries additionally needed
@@ -92,22 +77,17 @@ bool GettextStorage::load(const KUrl& url)
             while (msgstr.count()<m_numberOfPluralForms)
                 msgstr.append(QString());
             item.setMsgstr(msgstr);
-
         }
         ++i;
 
     }
+    //qCompress(m_storage->m_catalogExtraData.join("\n\n").toUtf8(),9);
 
-
-    return status==OK;
-
+    return status==OK?0:(errorLine+1);
 }
 
-bool GettextStorage::save(const KUrl& url)
+bool GettextStorage::save(QIODevice* device)
 {
-    bool remote=false;
-    KTemporaryFile tmpFile;
-
     QString header=m_header.msgstr();
     QString comment=m_header.comment();
     updateHeader(header,
@@ -123,31 +103,11 @@ bool GettextStorage::save(const KUrl& url)
     GettextExportPlugin exporter(m_maxLineLength>70?m_maxLineLength:-1, m_trailingNewLines);// this is kinda hackish...
 
     ConversionStatus status = OK;
+    status = exporter.save(device/*x-gettext-translation*/,this);
 
-    QString localFile;
-    if (KDE_ISLIKELY( url.isLocalFile() ))
-    {
-        localFile = url.path();
-        if (!QFile::exists(url.directory()))
-            KIO::NetAccess::mkdir(url.upUrl(),0);//recursion?..
-    }
-    else
-    {
-        remote=true;
-        tmpFile.open();
-        localFile=tmpFile.fileName();
-        tmpFile.close();
-    }
-
-    //kWarning() << "SAVE NAME "<<localFile;
-    status = exporter.save(localFile/*x-gettext-translation*/,this);
-
-    if (KDE_ISUNLIKELY( status!=OK || (remote && !KIO::NetAccess::upload( localFile, url, NULL) )))
-        return false;
-
-    return true;
-
+    return status==OK;
 }
+
 //END OPEN/SAVE
 
 //BEGIN STORAGE TRANSLATION
@@ -157,16 +117,41 @@ int GettextStorage::size() const
     return m_entries.size();
 }
 
-void GettextStorage::clear()
+
+static const QChar altSep(156);
+static InlineTag makeInlineTag(int i)
 {
+    static const QString altSepText(" | ");
+    static const QString ctype=i18n("separator for different-length string alternatives");
+    return InlineTag(i,i,InlineTag::x,QString::number(i),QString(),altSepText,ctype);
 }
 
-bool GettextStorage::isEmpty() const
+static CatalogString makeCatalogString(const QString& string)
 {
-    return m_entries.isEmpty();
+    CatalogString result;
+    result.string=string;
+    
+    int i=0;
+
+    while((i=result.string.indexOf(altSep, i))!=-1)
+    {
+        result.string[i]=TAGRANGE_IMAGE_SYMBOL;
+        result.tags.append(makeInlineTag(i));
+        ++i;
+    }
+    return result;
 }
 
 //flat-model interface (ignores XLIFF grouping)
+CatalogString GettextStorage::sourceWithTags(DocPosition pos) const
+{
+    return makeCatalogString(source(pos));
+}
+CatalogString GettextStorage::targetWithTags(DocPosition pos) const
+{
+    return makeCatalogString(target(pos));
+}
+
 QString GettextStorage::source(const DocPosition& pos) const
 {
     return m_entries.at(pos.entry).msgid(pos.form);
@@ -176,7 +161,6 @@ QString GettextStorage::target(const DocPosition& pos) const
     return m_entries.at(pos.entry).msgstr(pos.form);
 }
 
-
 void GettextStorage::targetDelete(const DocPosition& pos, int count)
 {
     m_entries[pos.entry].d->_msgstrPlural[pos.form].remove(pos.offset, count);
@@ -190,6 +174,18 @@ void GettextStorage::setTarget(const DocPosition& pos, const QString& arg)
     m_entries[pos.entry].d->_msgstrPlural[pos.form]=arg;
 }
 
+
+void GettextStorage::targetInsertTag(const DocPosition& pos, const InlineTag& tag)
+{
+    targetInsert(pos,altSep);
+}
+
+InlineTag GettextStorage::targetDeleteTag(const DocPosition& pos)
+{
+    targetDelete(pos,1);
+    return makeInlineTag(pos.offset);
+}
+
 QStringList GettextStorage::sourceAllForms(const DocPosition& pos) const
 {
     return m_entries[pos.entry].d->_msgidPlural.toList();
@@ -199,31 +195,139 @@ QStringList GettextStorage::targetAllForms(const DocPosition& pos) const
     return m_entries[pos.entry].d->_msgstrPlural.toList();
 }
 
-//DocPosition.form - number of <note>
-QString GettextStorage::note(const DocPosition& pos) const
+QVector<AltTrans> GettextStorage::altTrans(const DocPosition& pos) const
 {
-    return m_entries.at(pos.entry).comment();
-}
-int GettextStorage::noteCount(const DocPosition& pos) const
-{
-    return m_entries.at(pos.entry).comment().isEmpty()?0:1;
+    QStringList prev=m_entries.at(pos.entry).comment().split('\n').filter(QRegExp("^#\\|"));
+
+    QString oldSingular;
+    QString oldPlural;
+
+    QString* cur=&oldSingular;
+    QStringList::iterator it=prev.begin();
+    static const QString msgid_plural_alt="#| msgid_plural \"";
+    while (it!=prev.end())
+    {
+        if (it->startsWith(msgid_plural_alt))
+            cur=&oldPlural;
+
+        int start=it->indexOf('\"')+1;
+        int end=it->lastIndexOf('\"');
+        if (start&&end!=-1)
+        {
+            if (!cur->isEmpty())
+                (*cur)+='\n';
+            if (!(  cur->isEmpty() && (end-start)==0 ))//for multiline msgs
+                (*cur)+=it->midRef(start,end-start);
+        }
+        ++it;
+    }
+    if (pos.form==0)
+        cur=&oldSingular;
+
+    cur->replace("\\\"","\"");
+
+    QVector<AltTrans> result;
+    if (!cur->isEmpty())
+        result<<AltTrans(CatalogString(*cur));
+
+    return result;
 }
 
-//DocPosition.form - number of <context>
-QString GettextStorage::context(const DocPosition& pos) const
+Note GettextStorage::setNote(DocPosition pos, const Note& note)
 {
-    return m_entries.at(pos.entry).msgctxt();
+    //kWarning()<<"s"<<m_entries.at(pos.entry).comment();
+    Note oldNote;
+    QVector<Note> l=notes(pos);
+    if (l.size()) oldNote=l.first();
+
+    QStringList comment=m_entries.at(pos.entry).comment().split('\n');
+    //remove previous comment;
+    QStringList::iterator it=comment.begin();
+    while (it!=comment.end())
+    {
+        if (it->startsWith("# "))
+            it=comment.erase(it);
+        else
+            ++it;
+    }
+    if (note.content.size())
+        comment.prepend("# "+note.content.split('\n').join("\n# "));
+    m_entries[pos.entry].setComment(comment.join("\n"));
+
+    //kWarning()<<"e"<<m_entries.at(pos.entry).comment();
+    return oldNote;
 }
-int GettextStorage::contextCount(const DocPosition& pos) const
+
+QVector<Note> GettextStorage::notes(const DocPosition& docPosition, const QRegExp& re, int preLen) const
 {
-    return m_entries.at(pos.entry).msgctxt().isEmpty()?0:1;
+    QVector<Note> result;
+    QString content;
+
+    QStringList note=m_entries.at(docPosition.entry).comment().split('\n').filter(re);
+
+    foreach(const QString &s, note)
+    {
+        if (s.size()>=preLen)
+        {
+            content+=s.midRef(preLen);
+            content+='\n';
+        }
+    }
+
+    if (!content.isEmpty())
+    {
+        content.chop(1);
+        result<<Note(content);
+    }
+    return result;
+
+//i18nc("@info PO comment parsing. contains filename","<i>Place:</i>");
+//i18nc("@info PO comment parsing","<i>GUI place:</i>");
+}
+
+QVector<Note> GettextStorage::notes(const DocPosition& docPosition) const
+{
+    static const QRegExp nre("^# ");
+    return notes(docPosition,nre,2);
+}
+
+QVector<Note> GettextStorage::developerNotes(const DocPosition& docPosition) const
+{
+    static const QRegExp dnre("^#\\. (?!i18n: file:)");
+    return notes(docPosition,dnre,3);
+}
+
+QStringList GettextStorage::sourceFiles(const DocPosition& pos) const
+{
+    QStringList result;
+    QStringList commentLines=m_entries.at(pos.entry).comment().split('\n');
+
+    static const QRegExp i18n_file_re("^#. i18n: file: ");
+    foreach(const QString &uiLine, commentLines.filter(i18n_file_re))
+    {
+        //QStringList uiFiles=uiLine.mid(15).split(' ');
+        result+=uiLine.mid(15).split(' ');
+    }
+    bool hasUi=!result.isEmpty();
+
+    static const QRegExp cpp_re("^#: ");
+    foreach(const QString &cppLine, commentLines.filter(cpp_re))
+    {
+        if (hasUi && cppLine.startsWith("#: rc.cpp")) continue;
+        QStringList cppFiles=cppLine.mid(3).split(' ');
+        result+=cppFiles;
+    }
+    return result;
+}
+
+QStringList GettextStorage::context(const DocPosition& pos) const
+{
+    return matchData(pos);
 }
 
 QStringList GettextStorage::matchData(const DocPosition& pos) const
 {
     QString ctxt=m_entries.at(pos.entry).msgctxt();
-    if (ctxt.isEmpty())
-        return QStringList();
 
     //KDE-specific
     //Splits @info:whatsthis and actual note
@@ -242,7 +346,8 @@ QString GettextStorage::id(const DocPosition& pos) const
     //only if their msgctxts are different
 
     QString result=source(pos);
-    result+=m_entries.at(pos.entry).msgctxt();
+    result.remove('\n');
+    result.prepend(m_entries.at(pos.entry).msgctxt()+":\n");
     return result;
 /*    QByteArray result=source(pos).toUtf8();
     result+=m_entries.at(pos.entry).msgctxt().toUtf8();
@@ -266,7 +371,7 @@ void GettextStorage::setApproved(const DocPosition& pos, bool approved)
         m_entries[pos.entry].setFuzzy();
 }
 
-bool GettextStorage::isUntranslated(const DocPosition& pos) const
+bool GettextStorage::isEmpty(const DocPosition& pos) const
 {
     return m_entries.at(pos.entry).isUntranslated();
 }
@@ -283,9 +388,9 @@ bool GettextStorage::setHeader(const CatalogItem& newHeader)
    {
       // normalize the values - ensure every key:value pair is only on a single line
       QString values = newHeader.msgstr();
-      values.remove ("\n");
+      values.remove ('\n');
       values.replace ("\\n", "\\n\n");
-      kDebug () << "Normalized header: " << values;
+//       kDebug () << "Normalized header: " << values;
       QString comment=newHeader.comment();
 
       updateHeader(values,
