@@ -33,45 +33,63 @@
 
 #include "flowlayout.h"
 #include "termlabel.h"
+//#include "project.h"
 
+// #include <klocale.h>
 #include <kdebug.h>
 #include <kaction.h>
 
 using namespace GlossaryNS;
 
 FlowLayout::FlowLayout(User user,
-                       QWidget *parent,
                        QWidget *signalingWidget,
                        const QVector<KAction*>& actions,
                        int margin,
                        int spacing)
-        : QLayout(parent)
+        : QLayout()
         , m_index(0)
-        , m_signalingWidget(signalingWidget)
+        , m_receiver(signalingWidget)
 {
+    setSizeConstraint(QLayout::SetMinAndMaxSize);
     setMargin(margin);
     setSpacing(spacing);
-    setSizeConstraint(QLayout::SetMinAndMaxSize);
 
     if (user==glossary)
     {
-        int i=0;
-        for(;i<actions.size();++i)
+        foreach (KAction* action, actions)
         {
-            TermLabel* label=new TermLabel(actions.at(i)); /*this,m_keys.at(count())*/
-            connect(actions.at(i),SIGNAL(triggered(bool)),label,SLOT(insert()));
-            connect(label,SIGNAL(insertTerm(const QString&)),m_signalingWidget,SIGNAL(termInsertRequested(const QString&)));
+            TermLabel* label=new TermLabel(action); /*this,m_keys.at(count())*/
+            connect(action,SIGNAL(triggered(bool)),label,SLOT(insert()));
+            connect(label,SIGNAL(insertTerm(QString)),m_receiver,SIGNAL(termInsertRequested(QString)));
+            label->hide();
             addWidget(label);
         }
     }
+
+//     if (m_keys.isEmpty())
+//     {
+// //         Qt::Key key=Qt::Key_A;
+// //         for (;key<=Qt::Key_Z;++key)
+// //         {
+// //             if (KGlobalAccel::findActionNameSystemwide(Qt::ALT+key).isEmpty())
+// //             {
+// //                 keys.append(key);
+// //             }
+// //         }
+//         int i=(int)Qt::Key_A;
+//         for (;i<=(int)Qt::Key_Z;++i)
+//         {
+//             if (KGlobalAccel::findActionNameSystemwide(Qt::ALT+Qt::CTRL+(Qt::Key)i).isEmpty())
+//             {
+//                 m_keys.append((Qt::Key)i);
+//             }
+//         }
+// 
+//     }
+
 }
 
 
-FlowLayout::FlowLayout(int spacing)
-{
-    setSpacing(spacing);
-}
-
 FlowLayout::~FlowLayout()
 {
     QLayoutItem *item;
@@ -87,6 +105,15 @@ QLayoutItem *FlowLayout::takeAt(int index)
         return 0;
 }
 
+QLayoutItem *FlowLayout::itemAt(int index) const
+{
+    return itemList.value(index);
+}
+
+void FlowLayout::addItem(QLayoutItem *item) {itemList.append(item);}
+int FlowLayout::count() const {return itemList.size();}
+Qt::Orientations FlowLayout::expandingDirections() const {return 0;}
+bool FlowLayout::hasHeightForWidth() const {return true;}
 
 int FlowLayout::heightForWidth(int width) const
 {
@@ -100,12 +127,16 @@ void FlowLayout::setGeometry(const QRect &rect)
     doLayout(rect, false);
 }
 
+QSize FlowLayout::sizeHint() const
+{
+    return minimumSize();
+}
+
 QSize FlowLayout::minimumSize() const
 {
     QSize size;
-    QLayoutItem *item;
-    foreach (item, itemList)
-    size = size.expandedTo(item->minimumSize());
+    foreach (QLayoutItem* item, itemList)
+        size = size.expandedTo(item->minimumSize());
 
     size += QSize(2*margin(), 2*margin());
     return size;
@@ -117,8 +148,7 @@ int FlowLayout::doLayout(const QRect &rect, bool testOnly) const
     int y = rect.y();
     int lineHeight = 0;
 
-    QLayoutItem *item;
-    foreach (item, itemList)
+    foreach (QLayoutItem* item, itemList)
     {
         int nextX = x + item->sizeHint().width() + spacing();
         if (nextX - spacing() > rect.right() && lineHeight > 0)
@@ -141,23 +171,25 @@ int FlowLayout::doLayout(const QRect &rect, bool testOnly) const
 void FlowLayout::clearTerms()
 {
     setEnabled(false);
-    for (int i=0; i<count(); ++i)
-        static_cast<TermLabel*>(itemAt(i)->widget())->setVisible(false);
+    foreach (QLayoutItem* item, itemList)
+        static_cast<TermLabel*>(item->widget())->hide();
     m_index=0;
     setEnabled(true);
 }
 
-void FlowLayout::addTerm(const QString& term,int entry)
+void FlowLayout::addTerm(const QString& term, int entry, bool capFirst)
 {
+    //fill layout with labels
     while (m_index>=count())
     {
         TermLabel* label=new TermLabel;
-        connect(label,SIGNAL(insertTerm(const QString&)),m_signalingWidget,SIGNAL(termInsertRequested(const QString&)));
+        connect(label,SIGNAL(insertTerm(QString)),m_receiver,SIGNAL(termInsertRequested(QString)));
         addWidget(label);
     }
-    static_cast<TermLabel*>(itemAt(m_index)->widget())->setText(term,entry);
-    static_cast<TermLabel*>(itemAt(m_index)->widget())->setVisible(true);
+    TermLabel* label=static_cast<TermLabel*>(itemAt(m_index)->widget());
+    label->setText(term, entry, capFirst);
+    label->show();
     ++m_index;
-
 }
 
+
