@@ -35,6 +35,7 @@
 #include <QTime>
 #include <QFile>
 #include <QtAlgorithms>
+#include <QTimer>
 
 #undef KDE_NO_DEBUG_OUTPUT
 static int nodeCounter=0;
@@ -55,6 +56,7 @@ ProjectModel::ProjectModel(QObject *parent)
     , m_activeJob(NULL)
     , m_activeNode(NULL)
     , m_weaver(new ThreadWeaver::Weaver())
+    , m_completeScan(true)
 {
     m_weaver->setMaximumNumberOfThreads(1);
 
@@ -84,6 +86,10 @@ ProjectModel::ProjectModel(QObject *parent)
     connect(&m_potModel, SIGNAL(rowsRemoved(QModelIndex,int,int)),
             this, SLOT(pot_rowsRemoved(QModelIndex,int,int)));
 
+    m_doneTimer = new QTimer();
+    m_doneTimer->setSingleShot(true);
+    connect(m_doneTimer, SIGNAL(timeout()), this, SLOT(updateTotalsChanged()));
+
     setUrl(KUrl(), KUrl());
 }
 
@@ -131,6 +137,8 @@ void ProjectModel::setUrl(const KUrl &poUrl, const KUrl &potUrl)
     m_poUrl.adjustPath(KUrl::AddTrailingSlash);
     m_potUrl.adjustPath(KUrl::AddTrailingSlash);
 
+    emit loading();
+
     if (!poUrl.isEmpty())
         m_poModel.dirLister()->openUrl(m_poUrl, KDirLister::Reload);
     if (!potUrl.isEmpty())
@@ -176,7 +184,7 @@ KUrl ProjectModel::beginEditing(const QModelIndex& index)
 void ProjectModel::po_dataChanged(const QModelIndex& po_topLeft, const QModelIndex& po_bottomRight)
 {
     //nothing special here
-    //map from source and propogate
+    //map from source and propagate
     QModelIndex topLeft = indexForPoIndex(po_topLeft);
     QModelIndex bottomRight = indexForPoIndex(po_bottomRight);
 
@@ -188,7 +196,7 @@ void ProjectModel::po_dataChanged(const QModelIndex& po_topLeft, const QModelInd
 void ProjectModel::pot_dataChanged(const QModelIndex& pot_topLeft, const QModelIndex& pot_bottomRight)
 {
     //tricky here - some of the pot items may be represented by po items
-    //let's propogate that all subitems changed
+    //let's propagate that all subitems changed
 
 
     QModelIndex pot_parent = pot_topLeft.parent();
@@ -649,6 +657,18 @@ QVariant ProjectModel::data(const QModelIndex& index, int role) const
             default:
                 return QVariant();
         }
+    case FuzzyUntrCountRole:
+        return item.isFile()?(fuzzy + untranslated):0;
+    case FuzzyCountRole:
+        return item.isFile()?fuzzy:0;
+    case UntransCountRole:
+        return item.isFile()?untranslated:0;
+    case TemplateOnlyRole:
+        return item.isFile()?(node->poRowNumber == -1):0;
+    case TransOnlyRole:
+        return item.isFile()?(node->potRowNumber == -1):0;
+    case TotalRole:
+        return hasStats?(fuzzy + untranslated + translated):0;
     default:
         return QVariant();
     }
@@ -896,7 +916,7 @@ KUrl ProjectModel::poToPot(const KUrl& poPath) const
 
     //change ".po" into ".pot"
     if (pathToAdd.endsWith(".po")) //TODO: what about folders ??
-        pathToAdd = pathToAdd + "t";
+        pathToAdd+='t';
 
     KUrl potPath = m_potUrl;
     potPath.addPath(pathToAdd);
@@ -932,6 +952,8 @@ KUrl ProjectModel::potToPo(const KUrl& potPath) const
 
 void ProjectModel::enqueueNodeForMetadataUpdate(ProjectNode* node)
 {
+    m_doneTimer->stop();
+
     if (m_dirsWaitingForMetadata.contains(node))
     {
         if ((m_activeJob != NULL) && (m_activeNode == node))
@@ -963,6 +985,9 @@ void ProjectModel::deleteSubtree(ProjectNode* node)
 
 void ProjectModel::startNewMetadataJob()
 {
+    if (!m_completeScan) //hack for debugging
+        return;
+
     m_activeJob = NULL;
     m_activeNode = NULL;
 
@@ -1090,10 +1115,13 @@ void ProjectModel::setMetadataForDir(ProjectNode* node, const QList<KFileMetaInf
 
 void ProjectModel::updateDirStats(ProjectNode* node)
 {
-    if (node == &m_rootNode)
-        return;
-
     node->calculateDirStats();
+    if (node == &m_rootNode)
+    {
+        updateTotalsChanged();
+        return;
+    }
+
     updateDirStats(node->parent);
 
     if (node->parent->rows.count()==0 || node->parent->rows.count()>=node->rowNumber)
@@ -1107,6 +1135,33 @@ void ProjectModel::updateDirStats(ProjectNode* node)
     emit dataChanged(topLeft, bottomRight);
 }
 
+bool ProjectModel::updateDone(const QModelIndex& index, const KDirModel& model)
+{
+    if (model.canFetchMore(index))
+        return false;
+
+    int row=model.rowCount(index);
+    while (--row>=0)
+    {
+        if (!updateDone(model.index(row, 0, index), model))
+            return false;
+    }
+    return true;
+}
+
+void ProjectModel::updateTotalsChanged()
+{
+    bool done = m_dirsWaitingForMetadata.isEmpty();
+    if (done)
+    {
+        done = updateDone(m_poModel.indexForUrl(m_poUrl), m_poModel) &&
+               updateDone(m_potModel.indexForUrl(m_potUrl), m_potModel);
+        if (m_rootNode.fuzzy + m_rootNode.translated + m_rootNode.untranslated > 0 && !done)
+            m_doneTimer->start(2000);
+    }
+    emit totalsChanged(m_rootNode.fuzzy, m_rootNode.translated, m_rootNode.untranslated, done);
+}
+
 
 //ProjectNode class
 
