@@ -8,7 +8,7 @@
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy 
+  by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -80,7 +80,7 @@ class MyCompletionBox: public KCompletionBox
 public:
     MyCompletionBox(QWidget* p):KCompletionBox(p){}
     QSize sizeHint() const;
-    
+
     bool eventFilter(QObject* , QEvent* ); //reimplemented to deliver more keypresses to XliffTextEdit
 };
 
@@ -154,15 +154,33 @@ XliffTextEdit::XliffTextEdit(Catalog* catalog, DocPosition::Part part, QWidget*
     {
         connect (document(), SIGNAL(contentsChange(int,int,int)), this, SLOT(contentsChanged(int,int,int)));
         connect (this,SIGNAL(cursorPositionChanged()), this, SLOT(emitCursorPositionChanged()));
-        m_highlighter->setCurrentLanguage(Project::instance()->targetLangCode());
     }
-    else
-        m_highlighter->setCurrentLanguage(Project::instance()->sourceLangCode());
+    projectConfigChanged();
+    connect (Project::instance(),SIGNAL(configChanged()), this, SLOT(projectConfigChanged()));
 
     setSpellInterface(new XliffTextEditSpellInterface(m_highlighter));
     setHighlighter(m_highlighter);
 }
 
+void XliffTextEdit::projectConfigChanged()
+{
+    if (m_part==DocPosition::Target)
+    {
+        m_highlighter->setCurrentLanguage(Project::instance()->targetLangCode());
+
+        //"i use an english locale while translating kde pot files from english to hebrew"
+        QLocale targetLocale(Project::instance()->targetLangCode());
+        Qt::LayoutDirection targetLanguageDirection=Qt::LeftToRight;
+        if (targetLocale.language()==QLocale::Arabic || targetLocale.language()==QLocale::Hebrew
+            || targetLocale.language()==QLocale::Urdu || targetLocale.language()==QLocale::Persian
+            || targetLocale.language()==QLocale::Pashto)
+            targetLanguageDirection=Qt::RightToLeft;
+
+        setLayoutDirection(targetLanguageDirection);
+    }
+    else
+        m_highlighter->setCurrentLanguage(Project::instance()->sourceLangCode());
+}
 
 void XliffTextEdit::reflectApprovementState()
 {
@@ -228,7 +246,7 @@ CatalogString XliffTextEdit::showPos(DocPosition docPosition, const CatalogStrin
     else
         setContent(catalogString,refStr.string.isEmpty()?m_catalog->sourceWithTags(docPosition):refStr);
     connect (document(), SIGNAL(contentsChange(int,int,int)), this, SLOT(contentsChanged(int,int,int)));
-    
+
     _oldMsgstrAscii=document()->toPlainText();
 
     //BEGIN pos
@@ -470,7 +488,7 @@ void XliffTextEdit::contentsChanged(int offset, int charsRemoved, int charsAdded
         //kWarning()<<"char"<<editText[offset].unicode();
         if (charsAdded)
             m_catalog->push(new InsTextCmd(m_catalog,pos,addedText));
-        
+
     }
 
 /* TODO
@@ -486,7 +504,7 @@ void XliffTextEdit::contentsChanged(int offset, int charsRemoved, int charsAdded
     // for mergecatalog (remove entry from index)
     // and for statusbar
     emit contentsModified(m_currentPos);
-    
+
     if (charsAdded==1)
         doCompletion(offset+1);
 
@@ -910,7 +928,7 @@ int XliffTextEdit::strForMicePosIfUnderTag(QPoint mice, CatalogString& str)
 //         //try harder
 //         if (--pos>=0 && str.string.at(pos)==TAGRANGE_IMAGE_SYMBOL)
 //         {
-//             
+//
 //         }
 
         return -1;
@@ -1054,7 +1072,7 @@ void XliffTextEdit::spellReplace()
     const QStringList& suggestions=m_highlighter->suggestionsForWord(wordSelectCursor.selectedText());
     if (suggestions.isEmpty())
         return;
-            
+
     m_catalog->beginMacro(i18nc("@item Undo action item","Replace text"));
     wordSelectCursor.insertText(suggestions.first());
     m_catalog->endMacro();
@@ -1260,7 +1278,7 @@ void XliffTextEdit::doCompletion(int pos)
     }
 
     QStringList s=CompletionStorage::instance()->makeCompletion(target.mid(sp+1,len));
-    
+
     if (!m_completionBox)
     {
         m_completionBox=new MyCompletionBox(this);
