@@ -12,11 +12,11 @@
 #ifndef MESSAGEWIDGETLIST_H
 #define MESSAGEWIDGETLIST_H
 
-#include <qptrlist.h>
+#include <qlist.h>
 
 class MessageWidget;
 
-typedef QPtrList<MessageWidget> MessageWidgetList;
-typedef QPtrListIterator<MessageWidget> MessageWidgetListIt;
+typedef QList<MessageWidget*> MessageWidgetList;
+typedef QListIterator<MessageWidget*> MessageWidgetListIt;
 
 #endif
