@@ -16,6 +16,7 @@
 
 #include "umlnamespace.h"
 #include "umlobjectlist.h"
+#include "umlviewlist.h"
 #include "foreignkeyconstraint.h"
 #include "icon_utils.h"
 
@@ -23,7 +24,6 @@
 class UMLClassifier;
 class UMLPackage;
 class UMLEntity;
-class UMLForeignKeyConstraint;
 
 /**
  * General purpose model utilities.
@@ -41,6 +41,14 @@ UMLObject* findUMLObject( const UMLObjectList& inList,
                           Uml::Object_Type type = Uml::ot_UMLObject,
                           UMLObject *currentObj = NULL);
 
+void treeViewAddViews(const UMLViewList& viewList);
+void treeViewChangeIcon(UMLObject* object, Icon_Utils::Icon_Type to);
+void treeViewSetCurrentItem(UMLObject* object);
+void treeViewMoveObjectTo(UMLObject* container, UMLObject* object);
+UMLObject*  treeViewGetCurrentObject();
+UMLPackage* treeViewGetPackageFromCurrent();
+QString treeViewBuildDiagramName(Uml::IDType id);
+
 QString uniqObjectName(Uml::Object_Type type,
                        UMLPackage *parentPkg,
                        QString prefix = QString());
@@ -115,14 +123,6 @@ QString psText(Parse_Status value);
 
 QString updateDeleteActionToString( UMLForeignKeyConstraint::UpdateDeleteAction uda );
 
-/**
- * In a Q_OBJECT class define any enum as Q_ENUMS.
- * With the above the following macro returns the name of a given enum.
- * This can be used in debug output.
- * TODO: convert it to a function.
- */
-#define ENUM_NAME(o,e,v) (o::staticMetaObject.enumerator(o::staticMetaObject.indexOfEnumerator(#e)).valueToKey((v)))
-
 }
 
 #endif
